"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var format_1 = require("./format");
var unitValueArithmetic_1 = require("./unitValueArithmetic");
function createMeasureClass(num) {
    var InternalMeasure = /** @class */ (function () {
        function InternalMeasure(value, unit, symbol) {
            this.value = value;
            this.unit = unit;
            this.symbol = symbol;
        }
        // Arithmetic
        InternalMeasure.prototype.plus = function (other) {
            return new InternalMeasure(num.add(this.value, other.value), this.unit);
        };
        InternalMeasure.prototype.minus = function (other) {
            return new InternalMeasure(num.sub(this.value, other.value), this.unit);
        };
        InternalMeasure.prototype.negate = function () {
            return new InternalMeasure(num.neg(this.value), this.unit);
        };
        InternalMeasure.prototype.scale = function (value) {
            return new InternalMeasure(num.mult(this.value, value), this.unit);
        };
        InternalMeasure.prototype.times = function (other) {
            return new InternalMeasure(num.mult(this.value, other.value), unitValueArithmetic_1.multiplyUnits(this.unit, other.unit));
        };
        InternalMeasure.prototype.over = function (other) {
            return new InternalMeasure(num.div(this.value, other.value), unitValueArithmetic_1.divideUnits(this.unit, other.unit));
        };
        InternalMeasure.prototype.per = function (other) {
            return this.over(other);
        };
        InternalMeasure.prototype.div = function (other) {
            return this.over(other);
        };
        InternalMeasure.prototype.toThe = function (power) {
            return new InternalMeasure(num.pow(this.value, power), unitValueArithmetic_1.exponentiateUnit(this.unit, power));
        };
        InternalMeasure.prototype.inverse = function () {
            return this.toThe(-1);
        };
        InternalMeasure.prototype.reciprocal = function () {
            return this.toThe(-1);
        };
        InternalMeasure.prototype.unsafeMap = function (valueMap, unitMap) {
            var newUnit = unitMap === undefined ? this.unit : unitMap(this.unit);
            return new InternalMeasure(valueMap(this.value), newUnit);
        };
        // Comparisons
        InternalMeasure.prototype.compare = function (other) {
            return num.compare(this.value, other.value);
        };
        InternalMeasure.prototype.lt = function (other) {
            return this.compare(other) < 0;
        };
        InternalMeasure.prototype.lte = function (other) {
            return this.compare(other) <= 0;
        };
        InternalMeasure.prototype.eq = function (other) {
            return this.compare(other) === 0;
        };
        InternalMeasure.prototype.neq = function (other) {
            return this.compare(other) !== 0;
        };
        InternalMeasure.prototype.gte = function (other) {
            return this.compare(other) >= 0;
        };
        InternalMeasure.prototype.gt = function (other) {
            return this.compare(other) > 0;
        };
        // Formatting
        InternalMeasure.prototype.toString = function () {
            return "" + num.format(this.value) + format_1.formatUnit(this.unit);
        };
        InternalMeasure.prototype.in = function (unit) {
            if (unit.symbol === undefined) {
                return this.toString();
            }
            var value = num.format(num.div(this.value, unit.value));
            return value + " " + unit.symbol;
        };
        InternalMeasure.prototype.withSymbol = function (symbol) {
            return new InternalMeasure(this.value, this.unit, symbol);
        };
        InternalMeasure.prototype.clone = function () {
            return new InternalMeasure(this.value, this.unit);
        };
        return InternalMeasure;
    }());
    InternalMeasure.prototype.squared = function () {
        return this.toThe(2);
    };
    InternalMeasure.prototype.cubed = function () {
        return this.toThe(3);
    };
    return InternalMeasure;
}
exports.createMeasureClass = createMeasureClass;
//# sourceMappingURL=genericMeasureClass.js.map