"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var genericMeasureFactory_1 = require("./genericMeasureFactory");
var unitValueArithmetic_1 = require("./unitValueArithmetic");
function wrapUnaryFn(f) {
    return function (x) { return x.unsafeMap(f); };
}
function wrapNaryFn(f) {
    return function (first) {
        var rest = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            rest[_i - 1] = arguments[_i];
        }
        return first.unsafeMap(function () { return f.apply(void 0, measureValues.apply(void 0, [first].concat(rest))); });
    };
}
function measureValues() {
    var measures = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        measures[_i] = arguments[_i];
    }
    return measures.map(function (measure) { return measure.value; });
}
var staticMethods = {
    abs: wrapUnaryFn(Math.abs),
    ceil: wrapUnaryFn(Math.ceil),
    floor: wrapUnaryFn(Math.floor),
    fround: wrapUnaryFn(Math.fround),
    round: wrapUnaryFn(Math.round),
    trunc: wrapUnaryFn(Math.trunc),
    hypot: wrapNaryFn(Math.hypot),
    sqrt: function (x) { return x.unsafeMap(Math.sqrt, unitValueArithmetic_1.sqrtUnit); },
    cbrt: function (x) { return x.unsafeMap(Math.sqrt, unitValueArithmetic_1.cbrtUnit); },
};
exports.Measure = genericMeasureFactory_1.createMeasureType({
    one: function () { return 1; },
    neg: function (x) { return -x; },
    add: function (x, y) { return x + y; },
    sub: function (x, y) { return x - y; },
    mult: function (x, y) { return x * y; },
    div: function (x, y) { return x / y; },
    pow: function (x, y) { return Math.pow(x, y); },
    compare: function (x, y) { return x - y; },
    format: function (x) { return "" + x; },
}, staticMethods);
//# sourceMappingURL=measure.js.map