import { GenericMeasure } from "../measure/genericMeasure";
import * as Base from "./base";
/** A measure without any unit */
export declare const Dimensionless: GenericMeasure<number, {}>;
export declare type Dimensionless = typeof Dimensionless;
/** meters */
export declare type Length = typeof Base.meters;
export declare const Length: Length;
/** kilograms */
export declare type Mass = typeof Base.kilograms;
export declare const Mass: Mass;
/** seconds */
export declare type Time = typeof Base.seconds;
export declare const Time: Time;
/** Amperes */
export declare type ElectricCurrent = typeof Base.amperes;
export declare const ElectricCurrent: ElectricCurrent;
/** Kelvin */
export declare type Temperature = typeof Base.kelvin;
export declare const Temperature: Temperature;
/** moles */
export declare type AmountOfSubstance = typeof Base.moles;
export declare const AmountOfSubstance: AmountOfSubstance;
/** candelas */
export declare type LuminousIntensity = typeof Base.candelas;
export declare const LuminousIntensity: LuminousIntensity;
/** bits */
export declare type Memory = typeof Base.bits;
export declare const Memory: Memory;
/** radians */
export declare type PlaneAngle = typeof Base.radians;
export declare const PlaneAngle: PlaneAngle;
/** steradians */
export declare type SolidAngle = typeof Base.steradians;
export declare const SolidAngle: SolidAngle;
/** 1 / s */
export declare const Frequency: GenericMeasure<number, {
    time: -1;
}>;
export declare type Frequency = typeof Frequency;
/** 1 / s^2 */
export declare const FrequencyDrift: GenericMeasure<number, {
    time: -2;
}>;
export declare type FrequencyDrift = typeof FrequencyDrift;
/** 1 / m^2 */
export declare const FuelEfficiency: GenericMeasure<number, {
    length: -2;
}>;
export declare type FuelEfficiency = typeof FuelEfficiency;
/** 1 / m */
export declare const Wavenumber: GenericMeasure<number, {
    length: -1;
}>;
export declare type Wavenumber = typeof Wavenumber;
/** m^2 */
export declare const Area: GenericMeasure<number, {
    length: 2;
}>;
export declare type Area = typeof Area;
/** m^3 */
export declare const Volume: GenericMeasure<number, {
    length: 3;
}>;
export declare type Volume = typeof Volume;
/** m ⋅ s */
export declare const Absement: GenericMeasure<number, {
    length: 1;
    time: 1;
}>;
export declare type Absement = typeof Absement;
/** m / s */
export declare const Velocity: GenericMeasure<number, {
    length: 1;
    time: -1;
}>;
export declare type Velocity = typeof Velocity;
/** m / s^2 */
export declare const Acceleration: GenericMeasure<number, {
    length: 1;
    time: -2;
}>;
export declare type Acceleration = typeof Acceleration;
/** m / s^3 */
export declare const Jerk: GenericMeasure<number, {
    length: 1;
    time: -3;
}>;
export declare type Jerk = typeof Jerk;
/** m / s^4 */
export declare const Jounce: GenericMeasure<number, {
    length: 1;
    time: -4;
}>;
export declare type Jounce = typeof Jounce;
/** m / s^5 */
export declare const Crackle: GenericMeasure<number, {
    length: 1;
    time: -5;
}>;
export declare type Crackle = typeof Crackle;
/** m^3 / s */
export declare const VolumetricFlow: GenericMeasure<number, {
    length: 3;
    time: -1;
}>;
export declare type VolumetricFlow = typeof VolumetricFlow;
/** kg / s */
export declare const MassFlowRate: GenericMeasure<number, {
    mass: 1;
    time: -1;
}>;
export declare type MassFlowRate = typeof MassFlowRate;
/** kg / m */
export declare const LinearDensity: GenericMeasure<number, {
    length: -1;
    mass: 1;
}>;
export declare type LinearDensity = typeof LinearDensity;
/** kg / m^2  */
export declare const AreaDensity: GenericMeasure<number, {
    length: -2;
    mass: 1;
}>;
export declare type AreaDensity = typeof AreaDensity;
/** kg / m^3 */
export declare const VolumeDensity: GenericMeasure<number, {
    length: -3;
    mass: 1;
}>;
export declare type VolumeDensity = typeof VolumeDensity;
/** kg ⋅ m / s^2 */
export declare const Force: GenericMeasure<number, {
    length: 1;
    mass: 1;
    time: -2;
}>;
export declare type Force = typeof Force;
/** km ⋅ m / s^3 */
export declare const Yank: GenericMeasure<number, {
    length: 1;
    mass: 1;
    time: -3;
}>;
export declare type Yank = typeof Yank;
/** kg / (m ⋅ s^2)  */
export declare const Pressure: GenericMeasure<number, {
    length: -1;
    mass: 1;
    time: -2;
}>;
export declare type Pressure = typeof Pressure;
/** m ⋅ s^2 / kg */
export declare const Compressibility: GenericMeasure<number, {
    length: 1;
    mass: -1;
    time: 2;
}>;
export declare type Compressibility = typeof Compressibility;
/** kg / (m ⋅ s) */
export declare const DynamicViscosity: GenericMeasure<number, {
    length: -1;
    mass: 1;
    time: -1;
}>;
export declare type DynamicViscosity = typeof DynamicViscosity;
/** kg / s^2 */
export declare const SurfaceTension: GenericMeasure<number, {
    mass: 1;
    time: -2;
}>;
export declare type SurfaceTension = typeof SurfaceTension;
/** kg ⋅ m / s  */
export declare const Momentum: GenericMeasure<number, {
    length: 1;
    mass: 1;
    time: -1;
}>;
export declare type Momentum = typeof Momentum;
/** kg ⋅ m^2 */
export declare const MomentOfInertia: GenericMeasure<number, {
    length: 2;
    mass: 1;
}>;
export declare type MomentOfInertia = typeof MomentOfInertia;
/** kg ⋅ m^2 / s^2 */
export declare const Energy: GenericMeasure<number, {
    length: 2;
    mass: 1;
    time: -2;
}>;
export declare type Energy = typeof Energy;
/** kg ⋅ m^2 / s^3 */
export declare const Power: GenericMeasure<number, {
    length: 2;
    mass: 1;
    time: -3;
}>;
export declare type Power = typeof Power;
/** kg / (m ⋅ s^3) */
export declare const PowerDensity: GenericMeasure<number, {
    length: -1;
    mass: 1;
    time: -3;
}>;
export declare type PowerDensity = typeof PowerDensity;
/** kg ⋅ m^2 / (s^3 ⋅ A) */
export declare const Voltage: GenericMeasure<number, {
    length: 2;
    mass: 1;
    time: -3;
    current: -1;
}>;
export declare type Voltage = typeof Voltage;
/** s ⋅ A */
export declare const ElectricCharge: GenericMeasure<number, {
    time: 1;
    current: 1;
}>;
export declare type ElectricCharge = typeof ElectricCharge;
/** s ⋅ A / m^3 */
export declare const ElectricChargeDensity: GenericMeasure<number, {
    length: -3;
    time: 1;
    current: 1;
}>;
export declare type ElectricChargeDensity = typeof ElectricChargeDensity;
/** A / m^2 */
export declare const ElectricCurrentDensity: GenericMeasure<number, {
    length: -2;
    current: 1;
}>;
export declare type ElectricCurrentDensity = typeof ElectricCurrentDensity;
/** s ⋅ A / m^2 */
export declare const ElectricDisplacement: GenericMeasure<number, {
    length: -2;
    time: 1;
    current: 1;
}>;
export declare type ElectricDisplacement = typeof ElectricDisplacement;
/** kg ⋅ m / (s^3 ⋅ A) */
export declare const EletricFieldStrength: GenericMeasure<number, {
    length: 1;
    mass: 1;
    time: -3;
    current: -1;
}>;
export declare type EletricFieldStrength = typeof EletricFieldStrength;
/** s^4 ⋅ A^2 / (kg ⋅ m^2) */
export declare const ElectricalCapacitance: GenericMeasure<number, {
    length: -2;
    mass: -1;
    time: 4;
    current: 2;
}>;
export declare type ElectricalCapacitance = typeof ElectricalCapacitance;
/** s^3 ⋅ A / (kg ⋅ m^2) */
export declare const ElectricalConductance: GenericMeasure<number, {
    length: -2;
    mass: -1;
    time: 3;
    current: 2;
}>;
export declare type ElectricalConductance = typeof ElectricalConductance;
/** s^3 ⋅ A^2 / (kg ⋅ m^3) */
export declare const ElectricalConductivity: GenericMeasure<number, {
    length: -3;
    mass: -1;
    time: 3;
    current: 2;
}>;
export declare type ElectricalConductivity = typeof ElectricalConductivity;
/** kg ⋅ m^2 / (s^3 ⋅ A^2) */
export declare const ElectricalResistance: GenericMeasure<number, {
    length: 2;
    mass: 1;
    time: -3;
    current: -2;
}>;
export declare type ElectricalResistance = typeof ElectricalResistance;
/** kg ⋅ m^3 / (s^3 ⋅ A^2) */
export declare const ElectricalResistivity: GenericMeasure<number, {
    length: 3;
    mass: 1;
    time: -3;
    current: -2;
}>;
export declare type ElectricalResistivity = typeof ElectricalResistivity;
/** kg ⋅ m^2 / (s^2 ⋅ A^2) */
export declare const ElectricalInductance: GenericMeasure<number, {
    length: 2;
    mass: 1;
    time: -2;
    current: -2;
}>;
export declare type ElectricalInductance = typeof ElectricalInductance;
/** s ⋅ A / m */
export declare const LinearChargeDensity: GenericMeasure<number, {
    length: -1;
    time: 1;
    current: 1;
}>;
export declare type LinearChargeDensity = typeof LinearChargeDensity;
/** s^4 ⋅ A^2 / (kg ⋅ m^3) */
export declare const Permittivity: GenericMeasure<number, {
    length: -3;
    mass: -1;
    time: 4;
    current: 2;
}>;
export declare type Permittivity = typeof Permittivity;
/** kg ⋅ m^2 / (s^2 ⋅ A) */
export declare const MagneticFlux: GenericMeasure<number, {
    length: 2;
    mass: 1;
    time: -2;
    current: -1;
}>;
export declare type MagneticFlux = typeof MagneticFlux;
/** kg / (s^2 ⋅ A) */
export declare const MagneticFluxDensity: GenericMeasure<number, {
    mass: 1;
    time: -2;
    current: -1;
}>;
export declare type MagneticFluxDensity = typeof MagneticFluxDensity;
/** kg ⋅ m / (s^2 ⋅ A^2)  */
export declare const MagneticPermeability: GenericMeasure<number, {
    length: 1;
    mass: 1;
    time: -2;
    current: -2;
}>;
export declare type MagneticPermeability = typeof MagneticPermeability;
/** A / m */
export declare const Magnetization: GenericMeasure<number, {
    length: -1;
    current: 1;
}>;
export declare type Magnetization = typeof Magnetization;
/** s^2 ⋅ A^2 / (kg ⋅ m^2) */
export declare const MagneticReluctance: GenericMeasure<number, {
    length: -2;
    mass: -1;
    time: 2;
    current: 2;
}>;
export declare type MagneticReluctance = typeof MagneticReluctance;
/** kg ⋅ m^3 / (s^2 ⋅ A) */
export declare const MagneticMoment: GenericMeasure<number, {
    length: 3;
    mass: 1;
    time: -2;
    current: -1;
}>;
export declare type MagneticMoment = typeof MagneticMoment;
/** kg ⋅ m / (s^2 ⋅ A) */
export declare const MagneticRigidity: GenericMeasure<number, {
    length: 1;
    mass: 1;
    time: -2;
    current: -1;
}>;
export declare type MagneticRigidity = typeof MagneticRigidity;
/** m^2 ⋅ A */
export declare const MagneticDipoleMoment: GenericMeasure<number, {
    length: 2;
    current: 1;
}>;
export declare type MagneticDipoleMoment = typeof MagneticDipoleMoment;
/** s^2 ⋅ A^2 / (kg ⋅ m) */
export declare const MagneticSusceptibility: GenericMeasure<number, {
    length: -1;
    mass: -1;
    time: 2;
    current: 2;
}>;
export declare type MagneticSusceptibility = typeof MagneticSusceptibility;
/** kg / s^3  */
export declare const Irradiance: GenericMeasure<number, {
    mass: 1;
    time: -3;
}>;
export declare type Irradiance = typeof Irradiance;
/** kg ⋅ m / (s^2 ⋅ K)  */
export declare const Entropy: GenericMeasure<number, {
    length: 2;
    mass: 1;
    time: -2;
    temperature: -1;
}>;
export declare type Entropy = typeof Entropy;
/** m^2 / (s^2 ⋅ K) */
export declare const SpecificHeat: GenericMeasure<number, {
    length: 2;
    time: -2;
    temperature: -1;
}>;
export declare type SpecificHeat = typeof SpecificHeat;
/** m^3 / kg  */
export declare const SpecificVolume: GenericMeasure<number, {
    length: 3;
    mass: -1;
}>;
export declare type SpecificVolume = typeof SpecificVolume;
/** kg ⋅ m / (s^3 ⋅ K)  */
export declare const ThermalConductivity: GenericMeasure<number, {
    length: 1;
    mass: 1;
    time: -3;
    temperature: -1;
}>;
export declare type ThermalConductivity = typeof ThermalConductivity;
/** s^3 ⋅ K / (kg ⋅ m^2) */
export declare const ThermalResistance: GenericMeasure<number, {
    length: -2;
    mass: -1;
    time: 3;
    temperature: 1;
}>;
export declare type ThermalResistance = typeof ThermalResistance;
/** 1 / K */
export declare const ThermalExpansionCoefficient: GenericMeasure<number, {
    temperature: -1;
}>;
export declare type ThermalExpansionCoefficient = typeof ThermalExpansionCoefficient;
/** K / m */
export declare const ThermalGradient: GenericMeasure<number, {
    length: -1;
    temperature: 1;
}>;
export declare type ThermalGradient = typeof ThermalGradient;
/** kg ⋅ m^2 / (s^2 ⋅ K ⋅ mol) */
export declare const MolarEntropy: GenericMeasure<number, {
    length: 2;
    mass: 1;
    time: -2;
    temperature: -1;
    substance: -1;
}>;
export declare type MolarEntropy = typeof MolarEntropy;
/** kg ⋅ m^2 / (s^2 ⋅ mol) */
export declare const MolarEnergy: GenericMeasure<number, {
    length: 2;
    mass: 1;
    time: -2;
    substance: -1;
}>;
export declare type MolarEnergy = typeof MolarEnergy;
/** mol / m^3 */
export declare const Molarity: GenericMeasure<number, {
    length: -3;
    substance: 1;
}>;
export declare type Molarity = typeof Molarity;
/** m^3 / mol */
export declare const MolarVolume: GenericMeasure<number, {
    length: 3;
    substance: -1;
}>;
export declare type MolarVolume = typeof MolarVolume;
/** mol / kg */
export declare const Molality: GenericMeasure<number, {
    mass: -1;
    substance: 1;
}>;
export declare type Molality = typeof Molality;
/** kg / mol  */
export declare const MolarMass: GenericMeasure<number, {
    mass: 1;
    substance: -1;
}>;
export declare type MolarMass = typeof MolarMass;
/** s^3 ⋅ A^2 / (kg ⋅ mol) */
export declare const MolarConductivity: GenericMeasure<number, {
    mass: -1;
    time: 3;
    current: 2;
    substance: -1;
}>;
export declare type MolarConductivity = typeof MolarConductivity;
/** mol / s */
export declare const CatalyticActivity: GenericMeasure<number, {
    time: -1;
    substance: 1;
}>;
export declare type CatalyticActivity = typeof CatalyticActivity;
/** m^3 / (s ⋅ mol) */
export declare const CatalyticEfficiency: GenericMeasure<number, {
    length: 3;
    time: -1;
    substance: -1;
}>;
export declare type CatalyticEfficiency = typeof CatalyticEfficiency;
/** mol / (m^3 ⋅ s)  */
export declare const ReactionRate: GenericMeasure<number, {
    length: -3;
    time: -1;
    substance: 1;
}>;
export declare type ReactionRate = typeof ReactionRate;
/** m^2 / s^2 */
export declare const RadiationDose: GenericMeasure<number, {
    length: 2;
    time: -2;
}>;
export declare type RadiationDose = typeof RadiationDose;
/** m^2 / s^3 */
export declare const RadiationDoseRate: GenericMeasure<number, {
    length: 2;
    time: -3;
}>;
export declare type RadiationDoseRate = typeof RadiationDoseRate;
/** s^2 ⋅ A / kg  */
export declare const ElectronMobility: GenericMeasure<number, {
    mass: -1;
    time: 2;
    current: 1;
}>;
export declare type ElectronMobility = typeof ElectronMobility;
/** kg ⋅ m^2 / s */
export declare const AngularMomentum: GenericMeasure<number, {
    length: 2;
    mass: 1;
    time: -1;
}>;
export declare type AngularMomentum = typeof AngularMomentum;
/** m^2 /s */
export declare const SpecificAngularMomentum: GenericMeasure<number, {
    length: 2;
    time: -1;
}>;
export declare type SpecificAngularMomentum = typeof SpecificAngularMomentum;
/** cd / m^2 */
export declare const Luminance: GenericMeasure<number, {
    length: -2;
    intensity: 1;
}>;
export declare type Luminance = typeof Luminance;
/** cd ⋅ sr */
export declare const LuminousFlux: GenericMeasure<number, {
    intensity: 1;
    solidAngle: 1;
}>;
export declare type LuminousFlux = typeof LuminousFlux;
/** cd ⋅ sr / m^2 */
export declare const Illuminance: GenericMeasure<number, {
    length: -2;
    intensity: 1;
    solidAngle: 1;
}>;
export declare type Illuminance = typeof Illuminance;
/** s ⋅ cd ⋅ sr */
export declare const LuminousEnergy: GenericMeasure<number, {
    time: 1;
    intensity: 1;
    solidAngle: 1;
}>;
export declare type LuminousEnergy = typeof LuminousEnergy;
/** s ⋅ cd ⋅ sr / m^2 */
export declare const LuminousExposure: GenericMeasure<number, {
    length: -2;
    time: 1;
    intensity: 1;
    solidAngle: 1;
}>;
export declare type LuminousExposure = typeof LuminousExposure;
/** s^3 ⋅ cd ⋅ sr / (kg ⋅ m^2) */
export declare const LuminousEfficiency: GenericMeasure<number, {
    length: -2;
    mass: -1;
    time: 3;
    intensity: 1;
    solidAngle: 1;
}>;
export declare type LuminousEfficiency = typeof LuminousEfficiency;
/** kg ⋅ m^2 / (s^3 ⋅ sr) */
export declare const RadiantIntensity: GenericMeasure<number, {
    length: 2;
    mass: 1;
    time: -3;
    solidAngle: -1;
}>;
export declare type RadiantIntensity = typeof RadiantIntensity;
/** kg ⋅ m / (s^3 ⋅ sr)  */
export declare const SpectralIntensity: GenericMeasure<number, {
    length: 1;
    mass: 1;
    time: -3;
    solidAngle: -1;
}>;
export declare type SpectralIntensity = typeof SpectralIntensity;
/** kg / (s^3 ⋅ sr) */
export declare const Radiance: GenericMeasure<number, {
    mass: 1;
    time: -3;
    solidAngle: -1;
}>;
export declare type Radiance = typeof Radiance;
/** kg / (m ⋅ s^3 ⋅ sr) */
export declare const SpectralRadiance: GenericMeasure<number, {
    length: -1;
    mass: 1;
    time: -3;
    solidAngle: -1;
}>;
export declare type SpectralRadiance = typeof SpectralRadiance;
/** rad / s */
export declare const AngularVelocity: GenericMeasure<number, {
    time: -1;
    planeAngle: 1;
}>;
export declare type AngularVelocity = typeof AngularVelocity;
/** rad / s^2 */
export declare const AngularAcceleration: GenericMeasure<number, {
    time: -2;
    planeAngle: 1;
}>;
export declare type AngularAcceleration = typeof AngularAcceleration;
